changeset 16963:80fb94b07db2

Truffle/Instrumentation: rename misleading field name in ProbeImpl
author Michael Van De Vanter <michael.van.de.vanter@oracle.com>
date Tue, 26 Aug 2014 20:02:42 -0700
parents f0c3de09f12a
children 41f66e61b39a
files graal/com.oracle.truffle.api/src/com/oracle/truffle/api/instrument/impl/InstrumentationNode.java
diffstat 1 files changed, 5 insertions(+), 5 deletions(-) [+]
line wrap: on
line diff
--- a/graal/com.oracle.truffle.api/src/com/oracle/truffle/api/instrument/impl/InstrumentationNode.java	Tue Aug 26 19:57:25 2014 -0700
+++ b/graal/com.oracle.truffle.api/src/com/oracle/truffle/api/instrument/impl/InstrumentationNode.java	Tue Aug 26 20:02:42 2014 -0700
@@ -343,18 +343,18 @@
          * {@link Node#getSourceSection()}, which is {@code null} for all instances of
          * {@link InstrumentationNode} since they have no corresponding source of their own.
          */
-        private final SourceSection source;
+        private final SourceSection probedSourceSection;
 
         /**
          * Constructor.
          *
          * @param source The {@link SourceSection} associated with this probe.
          * @param probeCallback The {@link ProbeCallback} to inform when tags have been added to
          *            this probe.
          */
-        private ProbeImpl(SourceSection source, ProbeCallback probeCallback) {
+        private ProbeImpl(SourceSection probedSourceSection, ProbeCallback probeCallback) {
             this.probeCallback = probeCallback;
-            this.source = source;
+            this.probedSourceSection = probedSourceSection;
             this.probeUnchanged = Truffle.getRuntime().createAssumption();
             this.next = null;
         }
@@ -363,7 +363,7 @@
          * Returns the {@link SourceSection} associated with this probe.
          */
         public SourceSection getSourceLocation() {
-            return source;
+            return probedSourceSection;
         }
 
         /**
@@ -343,18 +343,18 @@
          * Constructor.
          *
-         * @param source The {@link SourceSection} associated with this probe.
+         * @param probedSourceSection The {@link SourceSection} associated with this probe.
          * @param probeCallback The {@link ProbeCallback} to inform when tags have been added to
          *            this probe.